@@ -73,7 +73,7 @@ static QJsonValue variantToJson(const QVariant &v)
             if (!dt.isValid()) {
                 return {};
             }
-            if (dt.timeSpec() == Qt::TimeZone) {
+            if (dt.timeSpec() == Qt::TimeZone && dt.timeZone() != QTimeZone::utc()) {
                 QJsonObject dtObj;
                 dtObj.insert(QLatin1String("value"), dt.toString(Qt::ISODate));
                 dtObj.insert(QLatin1String("timezone"), QString::fromUtf8(dt.timeZone().id()));
@@ -180,8 +180,14 @@ static QVariant variantFromJson(const QJsonValue &v, int mt)
             return v.toString();
         case QMetaType::Double:
         case QMetaType::Float:
+            if (v.isString()) {
+                return v.toString().toDouble();
+            }
             return v.toDouble();
         case QMetaType::Int:
+            if (v.isString()) {
+                return v.toString().toInt();
+            }
             return v.toInt();
         case QMetaType::QDateTime:
         {
